<?php
/*
Simple:Press
Admin User Groups Support Functions
$LastChangedDate: 2012-03-24 13:49:54 -0700 (Sat, 24 Mar 2012) $
$Rev: 8214 $
*/

if (preg_match('#'.basename(__FILE__).'#', $_SERVER['PHP_SELF'])) die('Access denied - you cannot directly call this file');

# function to create a new user group
function spa_save_usergroups_new_usergroup() {
    check_admin_referer('forum-adminform_usergroupnew', 'forum-adminform_usergroupnew');

    # if no usergroup name supplied use a default name
    if (empty($_POST['usergroup_name'])) {
        $usergroupname = spa_text('New User Group');
    } else {
        $usergroupname = sp_filter_title_save(trim($_POST['usergroup_name']));
    }

    $usergroupdesc = sp_filter_title_save(trim($_POST['usergroup_desc']));
    $usergroupbadge = sp_filter_filename_save(trim($_POST['usergroup_badge']));

    if (isset($_POST['usergroup_join'])) {
		$usergroupjoin = 1;
	} else {
		$usergroupjoin = 0;
	}

    if (isset($_POST['usergroup_is_moderator'])) {
		$usergroupismod = 1;
	} else {
		$usergroupismod = 0;
	}

    # create the usergroup
    $success = spa_create_usergroup_row($usergroupname, $usergroupdesc, $usergroupbadge, $usergroupjoin, $usergroupismod, true);

    sp_reset_memberships();

    if ($success == false) {
        $mess = spa_text('New User Group Creation Failed!');
    } else {
        $mess = spa_text('New User Group Created');
    }
    return $mess;
}

# function to update an existing user group
function spa_save_usergroups_edit_usergroup() {
    check_admin_referer('forum-adminform_usergroupedit', 'forum-adminform_usergroupedit');

    $usergroupdata = array();
    $usergroup_id = sp_esc_int($_POST['usergroup_id']);
    $usergroupdata['usergroup_name'] = sp_filter_title_save(trim($_POST['usergroup_name']));
    $usergroupdata['usergroup_desc'] = sp_filter_title_save(trim($_POST['usergroup_desc']));
    $usergroupdata['usergroup_badge'] = sp_filter_filename_save(trim($_POST['usergroup_badge']));
    if (isset($_POST['usergroup_join'])) { $usergroupdata['usergroup_join'] = 1; } else { $usergroupdata['usergroup_join'] = 0; }
    if (isset($_POST['usergroup_is_moderator'])) { $usergroupdata['usergroup_is_moderator'] = 1; } else { $usergroupdata['usergroup_is_moderator'] = 0; }

    # update the user group info
	$sql = "UPDATE ".SFUSERGROUPS." SET ";
	$sql.= 'usergroup_name="'.$usergroupdata['usergroup_name'].'", ';
	$sql.= 'usergroup_desc="'.$usergroupdata['usergroup_desc'].'", ';
	$sql.= 'usergroup_badge="'.$usergroupdata['usergroup_badge'].'", ';
	$sql.= 'usergroup_join="'.$usergroupdata['usergroup_join'].'", ';
	$sql.= 'usergroup_is_moderator="'.$usergroupdata['usergroup_is_moderator'].'" ';
	$sql.= 'WHERE usergroup_id="'.$usergroup_id.'";';
    $success = spdb_query($sql);

    sp_reset_memberships();

    if ($success == false) {
        $mess = spa_text('User Group Update Failed!');
    } else {
        $mess = spa_text('User Group Record Updated');
        do_action('sph_usergroup_new', $usergroup_id);
    }
    return $mess;
}

function spa_save_usergroups_delete_usergroup() {
    check_admin_referer('forum-adminform_usergroupdelete', 'forum-adminform_usergroupdelete');

    $usergroup_id = sp_esc_int($_POST['usergroup_id']);

    # dont allow updates to the default user groups
    $usergroup = spa_get_usergroups_row($usergroup_id);
    if ($usergroup->usergroup_locked) {
        $mess = spa_text('Sorry, the default User Groups cannot be deleted.');
        return $mess;
    }

    # remove all memberships for this user group
    spdb_query("DELETE FROM ".SFMEMBERSHIPS." WHERE usergroup_id=".$usergroup_id);

	# remove any permission sets using this user group
	$permissions = spdb_table(SFPERMISSIONS, "usergroup_id=$usergroup_id");
	if ($permissions) {
		foreach ($permissions as $permission) {
			spa_remove_permission_data($permission->permission_id);
		}
	}

	# remove any group default permissions using this user group
	spdb_query("DELETE FROM ".SFDEFPERMISSIONS." WHERE usergroup_id=".$usergroup_id);

    # remove the user group
   	spdb_query("DELETE FROM ".SFMEMBERSHIPS." WHERE usergroup_id=".$usergroup_id);
    $success = spdb_query("DELETE FROM ".SFUSERGROUPS." WHERE usergroup_id=".$usergroup_id);
    if ($success == false) {
        $mess = spa_text('User Group Delete Failed!');
    } else {
        $mess = spa_text('User Group Deleted');

        # reset auths and memberships for everyone
        sp_reset_memberships();
        sp_reset_auths();

        do_action('sph_usergroup_del', $usergroup_id);
    }

    return $mess;
}

function spa_save_usergroups_add_members() {
    check_admin_referer('forum-adminform_membernew', 'forum-adminform_membernew');

    # add the users to the user group membership
    $usergroup_id = sp_esc_int($_POST['usergroup_id']);
    if (isset($_POST['member_id'])) $user_id_list = array_unique($_POST['member_id']);

    if (!isset($user_id_list)) {
	    $mess = spa_text('No Data Changed!');
		return $mess;
	}

	for ($x=0; $x<count($user_id_list); $x++) {
		$user_id = sp_esc_int($user_id_list[$x]);
		$check = sp_check_membership($usergroup_id, $user_id);
		if (empty($check)) $success = sp_add_membership($usergroup_id, $user_id);
 	   	if ($success == false) {
	    	$mess = spa_text('Member Add Failed!');
	    	return $mess;
		}

        # reset auths and memberships for added user
        sp_reset_memberships($user_id);
        sp_reset_auths($user_id);

		# update mod flag
 	   	sp_update_member_moderator_flag($user_id);
	}

    do_action('sph_usergroup_add', $usergroup_id);

    $mess = spa_text('Member(s) Added to User Group');
    return $mess;
}

function spa_save_usergroups_delete_members() {
    check_admin_referer('forum-adminform_memberdel', 'forum-adminform_memberdel');

    $usergroup_id = sp_esc_int($_POST['usergroupid']);
    $new_usergroup_id = $_POST['usergroup_id'];
    if (isset($_POST['dmember_id'])) $user_id_list = array_unique($_POST['dmember_id']);

	# make sure not moving to same user group
	if (!isset($user_id_list) || $usergroup_id == $new_usergroup_id) {
	    $mess = spa_text('No Data Changed!');
		return $mess;
	}

	for ($x=0; $x<count($user_id_list); $x++) {
		$user_id = sp_esc_int($user_id_list[$x]);
		$success = spdb_query("DELETE FROM ".SFMEMBERSHIPS." WHERE user_id=".$user_id." AND usergroup_id=".$usergroup_id);

	    if ($new_usergroup_id != -1) {
			$check = sp_check_membership($new_usergroup_id, $user_id);
			if (empty($check)) $success = sp_add_membership($new_usergroup_id, $user_id);
	    }

        # reset auths and memberships for added user
        sp_reset_memberships($user_id);
        sp_reset_auths($user_id);

		# update mod flag
	    sp_update_member_moderator_flag($user_id);
	}

    if ($new_usergroup_id != -1) {
	    $mess = spa_text('Member(s) Moved');

        do_action('sph_usergroup_moved', $usergroup_id);
	} else {
	    $mess = spa_text('Member(s) Deleted From User Group');

        do_action('sph_usergroup_remove', $usergroup_id);
	}

    return $mess;
}
?>