<?php
/*
Simple:Press
Desc:
$LastChangedDate: 2012-03-30 10:19:35 -0700 (Fri, 30 Mar 2012) $
$Rev: 8248 $
*/

if (preg_match('#'.basename(__FILE__).'#', $_SERVER['PHP_SELF'])) die('Access denied - you cannot directly call this file');

# ==========================================================================================
#
# 	GLOBAL Database Module
# 	Statistics Database Routines
#
#	sp_track_online()
#	sp_get_members_online()
#	sp_is_online()
#	sp_get_stats_counts()
#	sp_get_post_stats()
#	sp_guests_browsing()
#	sp_track_logout()
#	sp_set_last_visited()
#
# ==========================================================================================

# ------------------------------------------------------------------
# sp_track_online()
#
# Tracks online users. Creates their new-post-list when they first
# appear through to saving their last visit date when they go again
# (either logout or time out - 20 minutes)
# ------------------------------------------------------------------
function sp_track_online() {
	global $spThisUser, $sfvars;

	if ($spThisUser->member) {
		# it's a member
		$trackUserId = $spThisUser->ID;
		$trackName = $spThisUser->user_login;
	} else {
		# Unknown guest
		$trackUserId = 0;
		$trackName = $spThisUser->ip;
	}

	# Update tracking
	$track = spdb_table(SFTRACK, "trackname='$trackName'", 'row');
	$now = current_time('mysql');

	$forumId = (isset($sfvars['forumid'])) ? $sfvars['forumid'] : 0;
	$topicId = (isset($sfvars['topicid'])) ? $sfvars['topicid'] : 0;
    $pageview = $sfvars['pageview'];

    # handle sneak peek
    if (!empty($topicId)) {
        if (!sp_get_auth('view_forum', $forumId)) return;
    } else if (!empty($forumId)) {
        if (!sp_get_auth('view_forum', $forumId) && !sp_get_auth('view_forum_topic_lists', $forumId)) return;
    }

    # update or start tracking
	if ($track) {
		# they are still here
		spdb_query("UPDATE ".SFTRACK."
				   SET trackdate='".$now."', forum_id=".$forumId.",  topic_id=".$topicId.", pageview='$pageview'
				   WHERE id=".$track->id);
		if($spThisUser->member) sp_update_users_newposts($spThisUser->newposts);
		$spThisUser->trackid = $track->id;
		$spThisUser->notification = $track->notification;
	} else {
		# newly arrived
		spdb_query("INSERT INTO ".SFTRACK."
			 	   (trackuserid, trackname, forum_id, topic_id, trackdate, pageview) VALUES
			 	   ($trackUserId, '$trackName', $forumId, $topicId, '$now', '$pageview')");
		$spThisUser->trackid = $sfvars['insertid'];
		if ($spThisUser->member) sp_construct_users_newposts();
	}

	# Check for expired tracking - some may have left the scene
	$splogin = sp_get_option('sflogin');
	$timeout = $splogin['sptimeout'];
	if(!$timeout) $timeout = 20;
	$expired = spdb_table(SFTRACK, "trackdate < DATE_SUB('$now', INTERVAL $timeout MINUTE)");
	if ($expired) {
		# if any Members expired - update user meta
		foreach ($expired as $expire) {
			if ($expire->trackuserid > 0) {
				sp_set_last_visited($expire->trackuserid);
				sp_destroy_users_newposts($expire->trackuserid);
			}
		}

		# finally delete them
		spdb_query("DELETE FROM ".SFTRACK."
					WHERE trackdate < DATE_SUB('$now', INTERVAL $timeout MINUTE)");
	}
}

# ------------------------------------------------------------------
# sp_get_track_id()
#
# Retrieves the track id for the current user. This function should
# only really be called from the sp_forum_api_support() function
# which should only ever be called from within the UI where we know
# there is a bona-fide user...
# ------------------------------------------------------------------
function sp_get_track_id() {
	global $spThisUser;

	if ($spThisUser->member) {
		# it's a member
		$trackUserId = $spThisUser->ID;
		$trackName = $spThisUser->user_login;
	} else {
		# Unknown guest
		$trackUserId = 0;
		$trackName = $spThisUser->ip;
	}
	$track = spdb_table(SFTRACK, "trackname='$trackName'", 'row');
	if($track) {
		$spThisUser->trackid = $track->id;
	}
}

# ------------------------------------------------------------------
# sp_get_members_online()
#
# Returns list of members currently tagged as online
# ------------------------------------------------------------------
function sp_get_members_online()
{
	return spdb_select('set', "
			SELECT trackuserid, display_name, user_options, forum_id, topic_id, pageview FROM ".SFTRACK."
			JOIN ".SFMEMBERS." ON ".SFTRACK.".trackuserid = ".SFMEMBERS.".user_id
			ORDER BY trackuserid");
}

# ------------------------------------------------------------------
# sp_is_online()
#
# Returns true if member is currently tagged as online
# ------------------------------------------------------------------
function sp_is_online($userid) {
	global $session_online;

	if (!$userid) return false;
	if (!isset($session_online)) $session_online = spdb_select('col', "SELECT trackuserid FROM ".SFTRACK);
	if (in_array($userid, $session_online)) return true;

	return false;
}

# ------------------------------------------------------------------
# sp_get_stats_counts()
#
# Returns stats on group/forum/topic/post count
# ------------------------------------------------------------------
function sp_get_stats_counts() {
	$cnt = '';
	$cnt->groups = 0;
	$cnt->forums = 0;
	$cnt->topics = 0;
	$cnt->posts = 0;

	$groupid = '';

	$forums = spdb_table(SFFORUMS, '', '', 'group_id');
	if ($forums) {
		foreach ($forums as $forum) {
			if ($forum->group_id != $groupid) {
				$groupid = $forum->group_id;
				$cnt->groups++;
			}
			$cnt->forums++;
			$cnt->topics+= $forum->topic_count;
			$cnt->posts+= $forum->post_count;
		}
	}
	return $cnt;
}

# ------------------------------------------------------------------
# sp_get_membership_stats()
#
# Returns stats on posts (admins/moderators and members and updates
# the guest count
# ------------------------------------------------------------------
function sp_get_membership_stats() {
	$stats = '';
	$admins = spdb_select('set', "
		SELECT SQL_CALC_FOUND_ROWS user_id, display_name, posts, admin, moderator
		FROM ".SFMEMBERS."
		WHERE admin=1");
	$stats->admins = spdb_select('var', "SELECT FOUND_ROWS()");

	$mods = spdb_select('set', "
		SELECT SQL_CALC_FOUND_ROWS user_id, display_name, posts, admin, moderator
		FROM ".SFMEMBERS."
		WHERE moderator=1");
	$stats->mods = spdb_select('var', "SELECT FOUND_ROWS()");

	$members = spdb_select('set', "
		SELECT SQL_CALC_FOUND_ROWS user_id, display_name, posts, admin, moderator
		FROM ".SFMEMBERS."
		WHERE admin=0 AND moderator=0");
	$stats->members = spdb_select('var', "SELECT FOUND_ROWS()");

	$guests = spdb_select('col', "
		SELECT DISTINCT guest_name
		FROM ".SFPOSTS."
		WHERE guest_name != ''");
	$stats->guests = count($guests);
	return $stats;
}

# ------------------------------------------------------------------
# sp_get_top_poster_stats()
#
# Returns stats on posts (admins/moderators and members and updates
# the guest count
# ------------------------------------------------------------------
function sp_get_top_poster_stats($count) {
	$topPosters = spdb_select('set', "
		SELECT SQL_CALC_FOUND_ROWS user_id, display_name, posts, admin, moderator
		FROM ".SFMEMBERS."
		WHERE admin=0 AND moderator=0 AND posts > -1
		ORDER BY posts DESC
		LIMIT 0,".$count.";");

	return $topPosters;
}

# ------------------------------------------------------------------
# sp_get_moderator_stats()
#
# Returns stats on posts (admins/moderators and members and updates
# the guest count
# ------------------------------------------------------------------
function sp_get_moderator_stats() {
	$mods = spdb_select('set', "
		SELECT user_id, display_name, posts, moderator
		FROM ".SFMEMBERS."
		WHERE moderator=1", ARRAY_A);
	return $mods;
}

# ------------------------------------------------------------------
# sp_get_admin_stats()
#
# Returns stats on posts (admins/moderators and members and updates
# the guest count
# ------------------------------------------------------------------
function sp_get_admin_stats() {
	$admins = spdb_select('set', "
		SELECT user_id, display_name, posts, admin
		FROM ".SFMEMBERS."
		WHERE admin=1", ARRAY_A);
	return $admins;
}

# ------------------------------------------------------------------
# sp_guests_browsing()
#
# Calculates how many guests are browsing current forum or topic
# ------------------------------------------------------------------
function sp_guests_browsing() {
	global $sfvars;

	$where = '';
	if ($sfvars['pageview'] == 'forum') $where = "forum_id=".$sfvars['forumid'];
	if ($sfvars['pageview'] == 'topic') $where = "topic_id=".$sfvars['topicid'];
	if (empty($where)) return;

	return spdb_count(SFTRACK, "trackuserid = 0 AND ".$where);
}

# ------------------------------------------------------------------
# sp_track_login()
#
# Filter Call
# Removes any sftrack record created when user was guest
# ------------------------------------------------------------------
function sp_track_login() {
	# if user was logged as guest before logging in, remove the guest entry
	$ip = sp_get_ip();
	spdb_query("DELETE FROM ".SFTRACK." WHERE trackname='".$ip."'");
}

# ------------------------------------------------------------------
# sp_track_logout()
#
# Filter Call
# Sets up the last visited upon user logout
# ------------------------------------------------------------------
function sp_track_logout() {
	global $current_user;

	sp_set_last_visited($current_user->ID);
	spdb_query("DELETE FROM ".SFTRACK." WHERE trackuserid=".$current_user->ID);
	sp_destroy_users_newposts($current_user->ID);
}

# ------------------------------------------------------------------
# sp_set_last_visited()
#
# Set the last visited timestamp after user has disappeared
#	$userid:		Users ID
# ------------------------------------------------------------------
function sp_set_last_visited($userid) {
	global $spThisUser;
	# before setting last visit check and save timezone difference just to be sure.
	$opts = sp_get_member_item($userid, 'user_options');
	if(!empty($opts['timezone_string'])) {
        if (preg_match('/^UTC[ \t+-]/', $opts['timezone_string'])) {
            # correct for manual UTC offets
            $userOffset = preg_replace('/UTC\+?/', '', $opts['timezone_string']) * 3600;
        } else {
            # get timezone offset for user
            $date_time_zone_selected = new DateTimeZone(sp_esc_str($opts['timezone_string']));
            $userOffset = timezone_offset_get($date_time_zone_selected, date_create());
        }
        $wptz = get_option('timezone_string');
		if (empty($wptz)) {
			$serverOffset = get_option('gmt_offset');
		} else {
			$date_time_zone_selected = new DateTimeZone($wptz);
			$serverOffset = timezone_offset_get($date_time_zone_selected, date_create());
		}
		# calculate time offset between user and server
		$ntz = (int) round(($userOffset - $serverOffset) / 3600, 2);
		if($opts['timezone'] != $ntz) {
			$opts['timezone'] = $ntz;
			$spThisUser->timezone = $ntz;
			sp_update_member_item($userid, 'user_options', $opts);
			sp_update_member_item($userid, 'checktime', 0);
		}
	}

	# Now set the last visit date/time
	sp_update_member_item($userid, 'lastvisit', 0);
}

?>