<?php
/*
Simple:Press
DESC: Admin functions for core, theme and plugin updates
$LastChangedDate: 2011-12-12 22:36:52 -0700 (Mon, 12 Dec 2011) $
$Rev: 7473 $
*/

if (preg_match('#'.basename(__FILE__).'#', $_SERVER['PHP_SELF'])) die('Access denied - you cannot directly call this file');

include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
class SP_Plugin_Upgrader extends WP_Upgrader {
	var $result;
	var $bulk = false;
	var $show_before = '';

	function upgrade_strings() {
		$this->strings['up_to_date'] 			= spa_text('The plugin is at the latest version');
		$this->strings['no_package'] 			= spa_text('Update package not available');
		$this->strings['downloading_package']	= spa_text('Downloading update from %s');
		$this->strings['unpack_package'] 		= spa_text('Unpacking the update...');
		$this->strings['deactivate_plugin'] 	= spa_text('Deactivating the plugin...');
		$this->strings['remove_old'] 			= spa_text('Removing the old version of the plugin...');
		$this->strings['remove_old_failed'] 	= spa_text('Could not remove the old plugin');
		$this->strings['process_failed'] 		= spa_text('Plugin update failed');
		$this->strings['process_success'] 		= spa_text('Plugin updated successfully');
	}

	function bulk_upgrade($plugins) {
		$this->init();
		$this->bulk = true;
		$this->upgrade_strings();

		$current = get_site_transient('sp_update_plugins');

		add_filter('upgrader_clear_destination', array(&$this, 'delete_old_plugin'), 10, 4);

		$this->skin->header();

		# Connect to the Filesystem first
		$res = $this->fs_connect(array(WP_CONTENT_DIR, SFPLUGINDIR));
		if (!$res) {
			$this->skin->footer();
			return false;
		}

		$this->skin->bulk_header();

		$this->maintenance_mode(false);

		$results = array();

		$this->update_count = count($plugins);
		$this->update_current = 0;
		foreach ($plugins as $plugin) {
			$this->update_current++;
			$this->skin->plugin_info = sp_get_plugin_data(SFPLUGINDIR.$plugin, false, true);

			if (!isset($current->response[$plugin])) {
				$this->skin->set_result(false);
				$this->skin->before();
				$this->skin->error('up_to_date');
				$this->skin->after();
				$results[$plugin] = false;
				continue;
			}

			# Get the URL to the zip file
			$r = $current->response[$plugin];

			$this->skin->plugin_active = sp_is_plugin_active($plugin);

			$result = $this->run(array(
						'package' 			=> $r->package,
						'destination' 		=> dirname(SFPLUGINDIR.$plugin),
						'clear_destination' => true,
						'clear_working' 	=> true,
						'is_multi' 			=> true,
						'hook_extra' 		=> array('plugin' => $plugin)
			));

			$results[$plugin] = $this->result;

			# Prevent credentials auth screen from displaying multiple times
			if (false === $result) break;
		} # end foreach $plugins

		$this->maintenance_mode(false);

		$this->skin->bulk_footer();

		$this->skin->footer();

		# Cleanup our hooks, incase something else does a upgrade on this connection
		remove_filter('upgrader_clear_destination', array(&$this, 'delete_old_plugin'));

		# Force refresh of plugin update information
		delete_site_transient('sp_update_plugins');

		return $results;
	}

	# Hooked to upgrade_clear_destination
	function delete_old_plugin($removed, $local_destination, $remote_destination, $plugin) {
		global $wp_filesystem;

		if (is_wp_error($removed)) return $removed; # Pass errors through

		$plugin = isset($plugin['plugin']) ? $plugin['plugin'] : '';
		if (empty($plugin)) return new WP_Error('bad_request', $this->strings['bad_request']);

		$plugins_dir = $wp_filesystem->find_folder(SFPLUGINDIR);
		$this_plugin_dir = trailingslashit(dirname($plugins_dir.$plugin));

		if (!$wp_filesystem->exists($this_plugin_dir)) return $removed; # If its already vanished

		# If plugin is in its own directory, recursively delete the directory.
		if (strpos($plugin, '/') && $this_plugin_dir != $plugins_dir) { # base check on if plugin includes directory separator AND that its not the root plugin folder
			$deleted = $wp_filesystem->delete($this_plugin_dir, true);
		} else {
			$deleted = $wp_filesystem->delete($plugins_dir.$plugin);
		}

		if (!$deleted) return new WP_Error('remove_old_failed', $this->strings['remove_old_failed']);

		return true;
	}
}

class Bulk_SP_Plugin_Upgrader_Skin extends Bulk_Upgrader_Skin {
	var $plugin_info = array(); # Plugin_Upgrader::bulk() will fill this in

	function __construct($args = array()) {
		parent::__construct($args);
	}

	function add_strings() {
		parent::add_strings();
		$this->upgrader->strings['skin_before_update_header'] = spa_text('Updating Plugin %1$s (%2$d/%3$d)');
	}

	function before() {
		parent::before($this->plugin_info['Name']);
	}

	function after() {
		parent::after($this->plugin_info['Name']);
	}

	function bulk_footer() {
		parent::bulk_footer();
		$update_actions =  array(
			'plugins_page' => '<a href="'.admin_url('admin.php?page=simple-press/admin/panel-plugins/spa-plugins.php').'" title="'.spa_text('Go to SP plugins page').'" target="_parent">'.spa_text('Go to SP plugins page').'</a>',
			'updates_page' => '<a href="'.self_admin_url('update-core.php').'" title="'.spa_text('Go to WordPress updates page').'" target="_parent">'.spa_text('Return to WordPress updates').'</a>'
		);

		$update_actions = apply_filters('sph_update_bulk_plugins_complete_actions', $update_actions, $this->plugin_info);
		if (!empty($update_actions)) $this->feedback(implode(' | ', (array)$update_actions));
	}
}

class SP_Theme_Upgrader extends WP_Upgrader {
	var $result;

	function upgrade_strings() {
		$this->strings['up_to_date'] 			= spa_text('The theme is at the latest version');
		$this->strings['no_package'] 			= spa_text('Update package not available');
		$this->strings['downloading_package'] 	= spa_text('Downloading update from %s');
		$this->strings['unpack_package'] 		= spa_text('Unpacking the update...');
		$this->strings['remove_old'] 			= spa_text('Removing the old version of the theme...');
		$this->strings['remove_old_failed'] 	= spa_text('Could not remove the old theme');
		$this->strings['process_failed'] 		= spa_text('Theme update failed');
		$this->strings['process_success'] 		= spa_text('Theme updated successfully');
	}

	function bulk_upgrade($themes) {
		$this->init();
		$this->bulk = true;
		$this->upgrade_strings();

		$current = get_site_transient('sp_update_themes');

		add_filter('upgrader_clear_destination', array(&$this, 'delete_old_theme'), 10, 4);

		$this->skin->header();

		# Connect to the Filesystem first
		$res = $this->fs_connect(array(SPTHEMEBASEDIR));
		if (!$res) {
			$this->skin->footer();
			return false;
		}

		$this->skin->bulk_header();

		$this->maintenance_mode(false);

		$results = array();

		$this->update_count = count($themes);
		$this->update_current = 0;

		foreach ($themes as $theme) {
			$this->update_current++;

			if (!isset($current->response[$theme])) {
				$this->skin->set_result(false);
				$this->skin->before();
				$this->skin->error('up_to_date');
				$this->skin->after();
				$results[$theme] = false;
				continue;
			}

			# Get the URL to the zip file
			$r = $current->response[$theme];

			include_once (SF_PLUGIN_DIR.'/admin/panel-themes/support/spa-themes-prepare.php');
			$theme_file = SPTHEMEBASEDIR.$theme.'/spTheme.txt';
			$this->skin->theme_info = sp_get_theme_data($theme_file, false, true);

			$options = array(
							'package' 			=> $r->package,
							'destination' 		=> dirname($theme_file),
							'clear_destination' => true,
							'clear_working' 	=> true,
							'hook_extra' 		=> array('theme' => $theme)
			);

			$result = $this->run($options);

			$results[$theme] = $this->result;

			# Prevent credentials auth screen from displaying multiple times
			if (false === $result) break;
		} # end foreach $themes


		$this->skin->bulk_footer();

		$this->skin->footer();

		# Cleanup our hooks, incase something else does a upgrade on this connection
		remove_filter('upgrader_clear_destination', array(&$this, 'delete_old_theme'), 10, 4);

		# Force refresh of theme update information
		delete_site_transient('sp_update_themes');

		return $results;
	}

	function delete_old_theme($removed, $local_destination, $remote_destination, $theme) {
		global $wp_filesystem;

		$theme = isset($theme['theme']) ? $theme['theme'] : '';

		if (is_wp_error($removed) || empty($theme)) return $removed; # Pass errors through

		$themes_dir = $wp_filesystem->find_folder(SPTHEMEBASEDIR);
		if ($wp_filesystem->exists($themes_dir.$theme)) {
			if (!$wp_filesystem->delete($themes_dir.$theme, true)) return false;
		}
		return true;
	}
}

class Bulk_SP_Theme_Upgrader_Skin extends Bulk_Upgrader_Skin {
	var $theme_info = array(); # Theme_Upgrader::bulk() will fill this in

	function __construct($args = array()) {
		parent::__construct($args);
	}

	function add_strings() {
		parent::add_strings();
		$this->upgrader->strings['skin_before_update_header'] = spa_text('Updating Theme %1$s (%2$d/%3$d)');
	}

	function before() {
		parent::before($this->theme_info['Name']);
	}

	function after() {
		parent::after($this->theme_info['Name']);
	}

	function bulk_footer() {
		parent::bulk_footer();
		$update_actions =  array(
			'plugins_page' => '<a href="'.admin_url('admin.php?page=simple-press/admin/panel-themes/spa-themes.php').'" title="'.spa_text('Go to SP themes page').'" target="_parent">'.spa_text('Go to SP themes page').'</a>',
			'updates_page' => '<a href="'.self_admin_url('update-core.php').'" title="'.spa_text('Go to WordPress updates page').'" target="_parent">'.spa_text('Return to WordPress updates').'</a>'
		);

		$update_actions = apply_filters('sph_update_bulk_themes_complete_actions', $update_actions, $this->theme_info);
		if (!empty($update_actions)) $this->feedback(implode(' | ', (array)$update_actions));
	}
}
?>